require(AER)
require(igraph)

#input <- list(nsims = 200, nobs = 500, strength = 8)

simdata <- function(nobs, strength, ate, excl.viol, direction){
  x1 <- rnorm(nobs)
  x2 <- rnorm(nobs)
  ins <- rnorm(nobs)
  t <- (.75*x1 - .3*x2 + strength*ins) > 0
  y <- rnorm(nobs, 3 + 4*x1 - 6*x2 + ate*t + ifelse(direction, 1, -1)*excl.viol*t, 2)
  data.frame(y, t, ins, x1, x2)
}

sim.all <- function(nsims, nobs, strength, ate, excl.viol, direction){
  res <- list()
  for(ii in 1:nsims){
    res[[ii]] <- simdata(nobs, strength, ate, excl.viol, direction)
  }
  res
}


naive.ate <- function(d){
  coef(lm(y ~ t, data = d))[2]
}

lm.ate <- function(d){
  coef(lm(y ~ t + x1, data = d))[2]
}

iv.ate <- function(d){
  coef(ivreg(y ~ t + x1| ins + x1, data = d))[2]
}

all.te <- function(d){
  data.frame(sapply(d, naive.ate),
             sapply(d, lm.ate),
             sapply(d, iv.ate))
}

graphit <- function(r, ate, tolerance = 10){
  ci <- rbind(colMeans(r) + (apply(r, 2, sd)/sqrt(nrow(r)) * 1.96),
              colMeans(r) - (apply(r, 2, sd)/sqrt(nrow(r)) * 1.96))
  
  range <- range(c(r, ate))
  if(diff(range) > ate*tolerance){
    range <- sort(c(ate - ate*(tolerance/2),ate + ate*(tolerance/2)))
  }
  
  par(mfrow = c(3,1))
  hist(r[,1],
       main = "Difference in Means Estimator",
       col = "red",
       xlab = "Estimated Treatment Effect",
       xlim = range,
       breaks = 10)
  abline(v = ate,
         col = "blue",
         lwd = 2)
  par(xpd = T)
  points(x = mean(r[,1]),
         y = par()$usr[3] - diff(par()$usr[3:4])*.1,
         pch = 18,
         cex = 2)
  segments(y0 = par()$usr[3] - diff(par()$usr[3:4])*.1,
           x0 = ci[1,1],
           x1 = ci[2,1])
  par(xpd = F)
  
  hist(r[,2],
       main = "Linear Regression, controlling for X1",
       col = "yellow",
       xlab = "Estimated Treatment Effect",
       xlim = range,
       breaks = 10)
  abline(v = ate,
         col = "blue",
         lwd = 2)
  par(xpd = T)
  points(x = mean(r[,2]),
         y = par()$usr[3] - diff(par()$usr[3:4])*.1,
         pch = 18,
         cex = 2)
  segments(y0 = par()$usr[3] - diff(par()$usr[3:4])*.1,
           x0 = ci[1,2],
           x1 = ci[2,2])
  par(xpd = F)
  
  
  hist(r[,3],
       main = "Instrumental Variables Estimator",
       col = "green",
       xlab = "Estimated Treatment Effect",
       xlim = range,
       breaks = 10)
  abline(v = ate,
         col = "blue",
         lwd = 2)
  par(xpd = T)
  points(x = mean(r[,3]),
         y = par()$usr[3] - diff(par()$usr[3:4])*.1,
         pch = 18,
         cex = 2)
  segments(y0 = par()$usr[3] - diff(par()$usr[3:4])*.1,
           x0 = ci[1,3],
           x1 = ci[2,3])
  par(xpd = F)
  
  par(mfrow = c(1,1))
}

