shinyUI(fluidPage(
  titlePanel("Understanding Instrumental Variables"),
  
  sidebarLayout(
    sidebarPanel(
      sliderInput("nobs", 
                  label = "Number of observations in each dataset",
                  min = 100, max = 1000, value = 250, step = 10),
      sliderInput("nsims", 
                  label = "Number of datsets to generate",
                  min = 50, max = 1000, value = 250, step = 10),
      #sliderInput("strength", 
      #            label = "How strong is the instrument?",
      #            min = -4, max = 4, value = 0, ticks = F),
      selectInput("strength",
                  label = "How strong is the instrument?", 
                  choices = list("1. Atrociously weak" = -4, 
                                 "2. Really weak" = -3,
                                 "3. Weak" = -2, 
                                 "4. A little bit weak" = -1,
                                 "5. Not too weak, not too strong" = 0,
                                 "6. A little bit strong" = 1,
                                 "7. Strong" = 2,
                                 "8. Really strong" = 3,
                                 "9. Ridiculously strong" = 4), selected = 0),
      checkboxInput("excl.yn",
                    label = "Violation to the exclusion restriction?"),
      uiOutput("excl2"),
      uiOutput("excl"),
      actionButton("sim.data",
                   "Simulate the datasets!",
                   icon = icon("thumbs-o-up", class = NULL, lib = "font-awesome")),
      br(),
      br(),
      p("Note: The true treatment effect is 3, noted by the blue vertical line. The data generation process here includes two confounders--X1 (observed) and U1 (unobserved)")
    ),
    
    mainPanel(p("This app was created by Stephen Pettigrew. Check out my website here:", 
                a("www.stephenpettigrew.com", href = "http://www.stephenpettigrew.com", target = "_blank")),
              br(),
              plotOutput("estfx"))
              
  )
))